# Generated by Django 4.0.5 on 2022-07-17 03:56

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('api', '0003_task_status'),
    ]

    operations = [
        migrations.AlterField(
            model_name='task',
            name='status',
            field=models.CharField(blank=True, default='New', max_length=100, null=True),
        ),
    ]
